#!/bin/bash
	
NODE_BIN="$1"
PARENT_TEST_FOLDER="$2"
TEST_LIST_FILE="$3"
BLACKLIST="$4"

# At most 10 min per test
TIMEOUT_DURATION=600
# Exit code
FINAL_RESULT=0 	
ARCH=$(uname -m)

# From blacklist extract ARCH to ignore
# If matches remove test from test-should-pass.txt
grep -v '^#' "$BLACKLIST" | while read -r line; do
    ARCH_IGNORE=$(echo "$line" | awk '{print $NF}')
    if [[ "$ARCH_IGNORE" != "$ARCH" ]]; then
        TEST_NAME=$(echo "$line" | awk '{$NF=""; print $0}' | sed 's/[[:space:]]*$//')
        sed -i "s|^$(echo "$TEST_NAME" | sed 's/[&/\]/\\&/g').*\n*||" "$TEST_LIST_FILE"
    fi
done
echo "Started test run:"
while IFS= read -r test_path; do
  TEST_SCRIPT="$PARENT_TEST_FOLDER/$test_path"
	
  if [ ! -f "$TEST_SCRIPT" ]; then
    echo "Test script not found: $TEST_SCRIPT"
    continue
  fi

  TEST_OUTPUT=$(timeout "$TIMEOUT_DURATION" "$NODE_BIN" "$TEST_SCRIPT" 2>&1)
  TEST_RESULT=$?
	
  if [ $TEST_RESULT -ne 0 ]; then
    FINAL_RESULT=1
    if [ $TEST_RESULT -eq 124 ]; then
      echo "Test timed out: $TEST_SCRIPT"
    else
      echo "Test failed: $TEST_SCRIPT"
    fi
    echo "Test failure message:"
    echo "$TEST_OUTPUT"
  fi
done < "$TEST_LIST_FILE"
if [ $FINAL_RESULT -eq 0 ]; then
    echo "All tests succesfully passed."
fi
exit $FINAL_RESULT
